Crate mrsbfh_macros

Crate mrsbfh_macros 

Attribute Macros

command
Used to define a command
command_generate
Used to generate the match case and help text
commands
Used to generate code to detect commands when we get a message for the bot

Derive Macros

ConfigDerive